import json
from pathlib import Path
from typing import Dict, Any
import importlib.resources

def load_character_config() -> Dict[str, Any]:
    # 使用 importlib.resources 安全访问包内文件
    with importlib.resources.path("nonebot_plugin_ds_baisuwen.data", "qq.json") as config_path:
        with open(config_path, 'r', encoding='utf-8') as f:
            return json.load(f)


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="nonebot-plugin-ds-baisuwen",
    version="1.1.6",
    packages=setuptools.find_packages(),
    install_requires=[
        "nonebot2>=2.0.0",
        "httpx>=0.23.0",
        "tenacity>=8.2.2",
        "redis>=4.5.1",
        "nonebot-adapter-onebot>=2.0.0"
    ],
    extras_require={
        "onebot-v11": ["nonebot-adapter-onebot-v11>=2.0.0"]
    },
    long_description=long_description,
    long_description_content_type="text/markdown"
)